#[non_exhaustive]pub enum Compatibility {
Exact,
Compatible {
dataset: BidsVersion,
library: BidsVersion,
},
Newer {
dataset: BidsVersion,
library: BidsVersion,
},
Incompatible {
reason: String,
},
}Expand description
Result of checking a dataset’s BIDS version against the library’s supported version.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Exact
Dataset version exactly matches the library’s target version.
Compatible
Dataset is from an older (but supported) spec version. Some newer features may not be present in the dataset.
Newer
Dataset declares a newer spec version than the library supports. The library may not understand new entities, datatypes, or conventions.
Incompatible
Dataset is fundamentally incompatible (different major version or below minimum supported version).
Implementations
Sourceimpl Compatibility
impl Compatibility
Sourcepub fn has_warnings(&self) -> bool
pub fn has_warnings(&self) -> bool
Returns true if processing may lose information or produce warnings.
Sourcepub fn is_incompatible(&self) -> bool
pub fn is_incompatible(&self) -> bool
Returns true if the dataset should not be processed.