pub struct BidsVersion {
pub major: u16,
pub minor: u16,
pub patch: u16,
}Expand description
A parsed BIDS specification version (SemVer).
Examples
use bids_schema::version::BidsVersion;
let v = BidsVersion::parse("1.9.0").unwrap();
assert_eq!(v.major, 1);
assert_eq!(v.minor, 9);
assert_eq!(v.patch, 0);
let older = BidsVersion::parse("1.6.0").unwrap();
assert!(v > older);
assert!(v.is_compatible_with(&older));Fields
major: u16minor: u16patch: u16Implementations
Sourceimpl BidsVersion
impl BidsVersion
Sourcepub fn parse(s: &str) -> Option<Self>
pub fn parse(s: &str) -> Option<Self>
Parse a version string like "1.9.0".
Accepts 2-part ("1.9") and 3-part ("1.9.0") versions.
Returns None if parsing fails.
Sourcepub fn is_compatible_with(&self, other: &BidsVersion) -> bool
pub fn is_compatible_with(&self, other: &BidsVersion) -> bool
Check whether this version is compatible with other.
Two versions are compatible if they share the same major version and
other is at least MIN_COMPATIBLE_VERSION.
Sourcepub fn is_older_than(&self, other: &BidsVersion) -> bool
pub fn is_older_than(&self, other: &BidsVersion) -> bool
Check whether other is from a newer spec than this version.
Sourcepub fn check_compatibility(
&self,
dataset_version: &BidsVersion,
) -> Compatibility
pub fn check_compatibility( &self, dataset_version: &BidsVersion, ) -> Compatibility
Return the compatibility status between this library version and a dataset’s declared BIDS version.